@@ -6,21 +6,6 @@ from agentmake.plugins.uba.lib.BibleParser import BibleVerseParser
 import re, apsw
 
 
-def luV(event):
-    """b, c, v = event.args
-    #ui.notify(f"b: {b}, c: {c}, v: {v}")
-    
-    # Create a context menu at the click position
-    with ui.context_menu() as menu:
-        ui.menu_item('Bible Commentaries', on_click=lambda: ui.navigate.to('/tool/commentary'))
-        ui.menu_item('Cross-references', on_click=lambda: ui.navigate.to('/tool/xref'))
-        ui.menu_item('Treasury of Scripture Knowledge', on_click=lambda: ui.navigate.to('/tool/tske'))
-        ui.menu_item('Discourse Analysis', on_click=lambda: ui.navigate.to('/tool/discourse'))
-        ui.menu_item('Morphological Data', on_click=lambda: ui.navigate.to('/tool/morphology'))
-        ui.menu_item('Translation Spectrum', on_click=lambda: ui.navigate.to('/tool/translations'))
-    menu.open()"""
-    pass
-
 def regexp(expr, item, case_sensitive=False):
     reg = re.compile(expr, flags=0 if case_sensitive else re.IGNORECASE)
     return reg.search(item) is not None
@@ -32,8 +17,9 @@ def get_bible_content(user_input, bible="NET", sql_query=""):
     refs = []
     results = []
     if re.search(" [0-9]+?:[0-9]", user_input):
-        refs = parser.extractAllReferences(user_input)
+        refs = parser.extractAllReferences(user_input, tagged=(True if '<ref onclick="bcv(' in user_input else False))
     if refs:
+        refs = list(set(refs))
         query = "SELECT Scripture FROM Verses WHERE Book=? AND Chapter=? AND Verse =?"
         with apsw.Connection(db) as connn:
             cursor = connn.cursor()
@@ -48,7 +34,7 @@ def get_bible_content(user_input, bible="NET", sql_query=""):
                         cursor.execute(query, (b, c, v))
                         verse = cursor.fetchone()
                         content += f"<vid>{v}</vid> {verse[0].strip()} "
-                    ref = parser.bcvToVerseReference(b, c, v)
+                    ref = parser.bcvToVerseReference(*ref)
                     results.append({'ref': ref, 'content': content.rstrip(), 'bible': bible, 'b': b1, 'c': c1, 'v': v1})
                 else:
                     b, c, v = ref
