@@ -8,6 +8,19 @@ import re, os
 
 def bible_translation(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, title="", **_):
 
+    bible_selector = BibleSelector(on_version_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_book_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_chapter_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_verse_changed=change_bible_chapter_verse)
+    
+    def luV(event):
+        nonlocal bible_selector
+        b, c, v = event.args
+        bible_selector.verse_select.value = v
+        """
+        # Create a context menu at the click position
+        with ui.context_menu() as menu:
+            ui.menu_item('Bible Commentaries', on_click=lambda: ...))
+            ui.menu_item('Cross-references', on_click=lambda: ...))
+        menu.open()"""
+
     ui.on('luV', luV)
 
     db = getBiblePath(title)
@@ -109,7 +122,6 @@ def bible_translation(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, tit
     ui.add_head_html(get_original_css(app.storage.user['dark_mode']))
 
     # Bible Selection menu
-    bible_selector = BibleSelector(on_version_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_book_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_chapter_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_verse_changed=change_bible_chapter_verse)
     def additional_items():
         nonlocal gui, bible_selector, area
         def previous_chapter(selection):
@@ -181,10 +193,20 @@ def bible_translation(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, tit
             app.storage.user['tool_book_text'], app.storage.user['tool_book_number'], app.storage.user['tool_chapter_number'], app.storage.user['tool_verse_number'] = selection
             gui.select_empty_area2_tab()
             gui.load_area_2_content(title="Audio", sync=False)
+        def search_bible(q=""):
+            app.storage.user['tool_query'] = q
+            gui.select_empty_area2_tab()
+            gui.load_area_2_content(title="Verses")
         with ui.button(icon='more_vert').props(f'flat round color={"white" if app.storage.user["dark_mode"] else "black"}'):
             with ui.menu():
-                ui.menu_item('Previous Chapter', on_click=lambda: previous_chapter(bible_selector.get_selection()))
+                ui.menu_item('Prev Chapter', on_click=lambda: previous_chapter(bible_selector.get_selection()))
                 ui.menu_item('Next Chapter', on_click=lambda: next_chapter(bible_selector.get_selection()))
+                if area == 1:
+                    ui.separator()
+                    ui.menu_item('Search Bible', on_click=lambda: search_bible())
+                    ui.menu_item('Search OT', on_click=lambda: search_bible(q="OT:::"))
+                    ui.menu_item('Search NT', on_click=lambda: search_bible(q="NT:::"))
+                    ui.menu_item(f'Search {bible_selector.book_select.value}', on_click=lambda: search_bible(q=f"{bible_selector.book_select.value}:::"))
                 ui.separator()
                 ui.menu_item('Bible Audio', on_click=lambda: change_audio_chapter(bible_selector.get_selection()))
     bible_selector.create_ui(title, b, c, v, additional_items=additional_items)
