@@ -17,9 +17,14 @@ from biblemategui.pages.bibles.original_discourse import original_discourse
 from biblemategui.pages.bibles.original_linguistic import original_linguistic
 from biblemategui.pages.bibles.bible_translation import bible_translation
 
+from biblemategui.pages.tools.xrefs import xrefs
 from biblemategui.pages.tools.audio import bibles_audio
 from biblemategui.pages.tools.chronology import bible_chronology
+
 from biblemategui.pages.search.bible_verses import search_bible_verses
+from biblemategui.pages.search.bible_promises import search_bible_promises
+from biblemategui.pages.search.bible_parallels import search_bible_parallels
+from biblemategui.pages.search.bible_topics import search_bible_topics
 
 class BibleMateGUI:
     def __init__(self):
@@ -280,7 +285,15 @@ class BibleMateGUI:
     def get_content(self, title):
         if title.lower() == "audio":
             return bibles_audio
-        elif title.lower() == "search":
+        elif title.lower() == "xrefs":
+            return xrefs
+        elif title.lower() == "promises":
+            return search_bible_promises
+        elif title.lower() == "parallels":
+            return search_bible_parallels
+        elif title.lower() == "topics":
+            return search_bible_topics
+        elif title.lower() == "verses":
             return search_bible_verses
         elif title.lower() == "chronology":
             return bible_chronology
@@ -354,7 +367,7 @@ class BibleMateGUI:
             print(traceback.format_exc())
 
     def is_tool(self, title):
-        tools = ("audio", "search", "chronology")
+        tools = ("audio", "verses", "chronology", "xrefs", "promises", "parallels", "topics")
         return True if title.lower() in tools else False
 
     def load_area_2_content(self, content=None, title="Tool", tab=None, args=None, keep=True, sync=True):
@@ -407,7 +420,17 @@ class BibleMateGUI:
         except:
             print(traceback.format_exc())
 
-    def change_area_1_bible_chapter(self, version, book=1, chapter=1, verse=1):
+    def get_area_1_bible_text(self):
+        active_bible_tab = self.get_active_area1_tab()
+        return app.storage.user[active_bible_tab]["bt"] if active_bible_tab in app.storage.user else app.storage.user['bible_book_text'] if 'bible_book_text' in app.storage.user else "NET"
+
+    def get_area_2_bible_text(self):
+        active_bible_tab = self.get_active_area2_tab()
+        return app.storage.user[active_bible_tab]["bt"] if active_bible_tab in app.storage.user else app.storage.user['tool_book_text'] if 'tool_book_text' in app.storage.user else "NET"
+
+    def change_area_1_bible_chapter(self, version=None, book=1, chapter=1, verse=1):
+        if version is None:
+            version = self.get_area_1_bible_text()
         app.storage.user['bible_book_text'] = version
         app.storage.user['bible_book_number'] = book
         app.storage.user['bible_chapter_number'] = chapter
@@ -433,7 +456,9 @@ class BibleMateGUI:
                 if config.reload_after_sync:
                     ui.run_javascript('location.reload()')
 
-    def change_area_2_bible_chapter(self, version, book=1, chapter=1, verse=1, sync=True):
+    def change_area_2_bible_chapter(self, version=None, book=1, chapter=1, verse=1, sync=True):
+        if version is None:
+            version = self.get_area_2_bible_text()
         app.storage.user['tool_book_text'] = version
         if sync and app.storage.user.get("sync"):
             app.storage.user['bible_book_number'] = book
@@ -641,7 +666,7 @@ class BibleMateGUI:
                             ui.menu_item('Compare Verse', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.separator()
                             ui.menu_item('Bible Commentaries', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Cross-references', on_click=lambda: self.load_area_2_content(self.work_in_progress))
+                            ui.menu_item('Cross-references', on_click=lambda: self.load_area_2_content(title='Xrefs'))
                             ui.menu_item('Treasury of Scripture Knowledge', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Discourse Analysis', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Morphological Data', on_click=lambda: self.load_area_2_content(self.work_in_progress))
@@ -655,16 +680,16 @@ class BibleMateGUI:
                     
                     with ui.button(icon='search').props('flat color=white round').tooltip('Search'):
                         with ui.menu():
-                            ui.menu_item('Bibles', on_click=lambda: self.load_area_2_content(title='Search'))
-                            ui.menu_item('Parallels', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Promises', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Topics', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Names', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Characters', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Locations', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Dictionary', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Encyclopedia', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Lexicon', on_click=lambda: self.load_area_2_content(self.work_in_progress))
+                            ui.menu_item('Bibles', on_click=lambda: self.load_area_2_content(title='verses'))
+                            ui.menu_item('Parallels', on_click=lambda: self.load_area_2_content(title='Parallels'))
+                            ui.menu_item('Promises', on_click=lambda: self.load_area_2_content(title='Promises'))
+                            ui.menu_item('Topics', on_click=lambda: self.load_area_2_content(title='Topics'))
+                            ui.menu_item('Names', on_click=lambda: self.load_area_2_content(title='Names'))
+                            ui.menu_item('Characters', on_click=lambda: self.load_area_2_content(title='Characters'))
+                            ui.menu_item('Locations', on_click=lambda: self.load_area_2_content(title='Locations'))
+                            ui.menu_item('Dictionaries', on_click=lambda: self.load_area_2_content(title='Dictionaries'))
+                            ui.menu_item('Encyclopedias', on_click=lambda: self.load_area_2_content(title='Encyclopedias'))
+                            ui.menu_item('Lexicons', on_click=lambda: self.load_area_2_content(title='Lexicons'))
 
                     with ui.button(icon='auto_awesome').props('flat color=white round').tooltip('AI'):
                         with ui.menu():
@@ -826,7 +851,7 @@ class BibleMateGUI:
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Cross-references', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Xrefs'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Treasury of Scripture Knowledge', on_click=lambda: (
@@ -857,43 +882,43 @@ class BibleMateGUI:
             # Search
             with ui.expansion('Search', icon='search').props('header-class="text-secondary"'):
                 ui.item('Bibles', on_click=lambda: (
-                    self.load_area_2_content(title='Search'),
+                    self.load_area_2_content(title='verses'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Parallels', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Parallels'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Promises', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Promises'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Topics', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Topics'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Names', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Names'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Characters', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Characters'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Locations', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Locations'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
-                ui.item('Dictionary', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                ui.item('Dictionaries', on_click=lambda: (
+                    self.load_area_2_content(title='Dictionaries'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
-                ui.item('Encyclopedia', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                ui.item('Encyclopedias', on_click=lambda: (
+                    self.load_area_2_content(title='Encyclopedias'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
-                ui.item('Lexicon', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                ui.item('Lexicons', on_click=lambda: (
+                    self.load_area_2_content(title='Lexicons'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
             
